#include <Python.h>
#include "rooting.hpp"
#include <stdexcept>

static PyObject* rooting_wrapper(PyObject* self, PyObject* args) {
    double number;  // Changed to double to accept floating-point numbers
    double n = 2.0;  // Default value for the second argument
    
    if (!PyArg_ParseTuple(args, "d|d", &number, &n)) {  // First arg required, second optional
        return NULL;
    }
    
    try {
        double result = rooting::nth_root(number, n);  // Pass number directly as double
        return PyFloat_FromDouble(result);
    } catch (const std::invalid_argument& e) {
        PyErr_SetString(PyExc_ValueError, e.what());
        return NULL;
    }
}

static PyMethodDef NthRootMethods[] = {
    {"rooting", rooting_wrapper, METH_VARARGS, "Compute the nth root of a number"},
    {NULL, NULL, 0, NULL}
};

static struct PyModuleDef sqrt_module = {
    PyModuleDef_HEAD_INIT,
    "fabelous_math.rooting",
    "Module for computing the nth root of a number",
    -1,
    NthRootMethods
};

PyMODINIT_FUNC PyInit_rooting(void) {
    return PyModule_Create(&sqrt_module);
}